@@ -104,6 +104,6 @@ if __name__ == '__main__':
         if paths['test']:
             for t in paths['test']:
                 logger.debug('watching %s' % t)
-                server.watch(paths['lib'][l]['input'], doc_tests(paths['test'][t]['output'], paths['lib'][l]['input']))
+                server.watch(paths['test'][l]['input'], doc_tests(paths['test'][t]['output'], paths['lib'][l]['input']))
 
         server.serve(host=args.host, port=args.port)
